#!/usr/bin/perl -w
#
# Nagios configuration generator (WLCG probe based)
# Copyright (c) 2007 Emir Imamagic
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package NCG::LocalMetricSets::Hash;

use NCG::LocalMetricSets;
use vars qw(@ISA);

@ISA=("NCG::LocalMetricSets");

sub new
{
    my $proto  = shift;
    my $class  = ref($proto) || $proto;
    my $self =  $class->SUPER::new(@_);

    $self;
}

sub getData {
    my $self = shift;

    foreach my $host ($self->{SITEDB}->getHosts()) {
        foreach my $service ($self->{SITEDB}->getServices($host)) {
            foreach my $metricSet (@{$WLCG_NODETYPE->{$service}->{services}}) {
                $self->{SITEDB}->addMetricSet($host, $metricSet, $service);
            }
        }
    }
}
    
########################################################################
########################################################################
#####
#####
#####       Hard coded Probe Description database
#####
#####
########################################################################
########################################################################

# table ServiceNodeType
$WLCG_NODETYPE->{BDII}->{services} = ["BDII"];
$WLCG_NODETYPE->{'Site-BDII'}->{services} = ["BDII"];
$WLCG_NODETYPE->{RB}->{services} = ["ResourceBroker","gsiftp","MDS-GIIS","CAdistribution","org.glite.LocalLogger"];
$WLCG_NODETYPE->{CE}->{services} = ["globus-GRAM","gsiftp","MDS-GIIS","CAdistribution","org.glite.LocalLogger"];

$WLCG_NODETYPE->{SE}->{services} = ["gsiftp","CAdistribution","MDS-GIIS"];
$WLCG_NODETYPE->{SRM}->{services} = ["SRM1","SRM2","BDII","MDS-GIIS","DPNS"];

$WLCG_NODETYPE->{MON}->{services} = ["it.infn.GridICE", "Tomcat", "gLite-RGMA"];
$WLCG_NODETYPE->{PROX}->{services} = ["MyProxy","MDS-GIIS"];
# LFC currently changing from MDS-GIIS to BDII, so could have either.
# non-existent one removed by active checks
$WLCG_NODETYPE->{LFC}->{services} = ["gLite-LFC","BDII", "MDS-GIIS"];
$WLCG_NODETYPE->{WMS}->{services} = ["gsiftp", "org.glite.wms.WMProxy","CAdistribution","org.glite.LocalLogger"];

# Not available on 3.1 UI - will get removed by ncg.pl by active checks
push @{$WLCG_NODETYPE->{WMS}->{services}}, "org.glite.wms.NetworkServer";

$WLCG_NODETYPE->{'gLite-CE'}->{services} = ["globus-GRAM","gsiftp","MDS-GIIS","CAdistribution"];
$WLCG_NODETYPE->{'gLite-FTS-WS'}->{services} = ["BDII", "Tomcat", "gLite-FTS-WS"];

$WLCG_NODETYPE->{VOBOX}->{services} = ["gsissh", "MDS-GIIS"];

########################################################################

=head1 NAME

NCG::LocalMetricSets::Hash

=head1 DESCRIPTION

The NCG::LocalMetricSets::Hash module extends NCG::LocalMetricSets
module. Module contains hardcoded list of metric set for each
service.

=head1 SYNOPSIS

  use NCG::LocalMetricSets::Hash;
  $ncg = NCG::LocalMetricSets::Hash->new( { SITEDB => $sitedb } );
  $ncg->getData();

=cut

=head1 METHODS

=over

=item C<new>

  $dbh = NCG::LocalMetricSets->new( $attr );

Creates new NCG::LocalMetricSets::Hash instance.

=back

=head1 SEE ALSO

NCG::LocalMetricSets

=cut

1;
