#!/usr/bin/perl -w
#
# Nagios configuration generator (WLCG probe based)
# Copyright (c) 2007 Emir Imamagic
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package NCG::LocalMetrics::Hash;

use NCG::LocalMetrics;
use vars qw(@ISA);

@ISA=("NCG::LocalMetrics");

sub new
{
    my $proto  = shift;
    my $class  = ref($proto) || $proto;
    my $self =  $class->SUPER::new(@_);
    
    # check if NATIVE really exists
    if (exists $self->{NATIVE})
    {
        my $test = 0;
        foreach my $service (keys %$WLCG_SERVICE) {
            foreach my $metric (keys %{$WLCG_SERVICE->{$service}->{metrics}}) {
                if (exists $WLCG_SERVICE->{$service}->{metrics}->{$metric}->{native} &&
                    $WLCG_SERVICE->{$service}->{metrics}->{$metric}->{native} eq $self->{NATIVE})
                {
                    $test = 1;
                    last;
                }
            }
            last if ($test);
        }
        if (!$test)
        {
            $self->error("There are no native metrics for defined NATIVE: " . $self->{NATIVE});
        }
    }

    $self;
}

sub getData {
    my $self = shift;
    my $nativeAllow = $self->{NATIVE};

    foreach my $host ($self->{SITEDB}->getHosts()) {
        foreach my $service ($self->{SITEDB}->getMetricSets($host)) {
            foreach my $metric (keys %{$WLCG_SERVICE->{$service}->{metrics}}) {
                my $metricRef = $WLCG_SERVICE->{$service}->{metrics}->{$metric};
                
                next if (defined $nativeAllow && exists $metricRef->{native} && $metricRef->{native} ne $nativeAllow);
                
                my $confRef = {};
                my $depRef = {};
                my $attrRef = {};

                $confRef = {%{$metricRef->{config}}} if (exists $metricRef->{config});
                $attrRef = {%{$metricRef->{attribute}}} if (exists $metricRef->{attribute});
                $depRef = {%{$metricRef->{dependency}}} if (exists $metricRef->{dependency});

                $self->{SITEDB}->addLocalMetric($host,
                                                $metric,
                                                $service,
                                                $metricRef->{probe},
                                                $metricRef->{native},
                                                $metricRef->{vo},
                                                $confRef,
                                                $attrRef,
                                                $depRef,
                                                $metricRef->{docurl});
            }
        }
    }
}
    
########################################################################
########################################################################
#####
#####
#####       Hard coded Probe Description database
#####
#####
########################################################################
########################################################################


my $SERVICE_TEMPL;

$SERVICE_TEMPL->{15}->{interval} = 15;
$SERVICE_TEMPL->{15}->{timeout} = 120;
$SERVICE_TEMPL->{15}->{retryInterval} = 5;

$SERVICE_TEMPL->{60}->{interval} = 60;
$SERVICE_TEMPL->{60}->{timeout} = 600;
$SERVICE_TEMPL->{60}->{retryInterval} = 15;

$SERVICE_TEMPL->{1440}->{interval} = 1440;
$SERVICE_TEMPL->{1440}->{timeout} = 120;
$SERVICE_TEMPL->{1440}->{retryInterval} = 60;


# GridFTP service
$WLCG_SERVICE->{gsiftp}->{metrics}->{'hr.srce.GridFTP-Transfer'}->{config} = {%{$SERVICE_TEMPL->{60}}};
$WLCG_SERVICE->{gsiftp}->{metrics}->{'hr.srce.GridFTP-Transfer'}->{probe} = 'hr.srce/GridFTP-probe';
$WLCG_SERVICE->{gsiftp}->{metrics}->{'hr.srce.GridFTP-Transfer'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
$WLCG_SERVICE->{gsiftp}->{metrics}->{'hr.srce.GridFTP-Transfer'}->{dependency}->{"org.nagios.GridFTP-Check"} = 1;
$WLCG_SERVICE->{gsiftp}->{metrics}->{'hr.srce.GridFTP-Transfer'}->{attribute}->{SE_PATH} = "--path";
#$WLCG_SERVICE->{gsiftp}->{metrics}->{'hr.srce.GridFTP-Transfer'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{gsiftp}->{metrics}->{'hr.srce.GridFTP-Transfer'}->{attribute}->{VONAME} = "-v";
$WLCG_SERVICE->{gsiftp}->{metrics}->{'hr.srce.GridFTP-Transfer'}->{vo} = 1;

# GRAM service
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Auth'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Auth'}->{probe} = 'hr.srce/GRAM-probe';
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Auth'}->{dependency}->{"hr.srce.GRAM-CertLifetime"} = 1;
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Auth'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
#$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Auth'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Auth'}->{attribute}->{VONAME} = "-v";
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Auth'}->{vo} = 1;

$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Command'}->{config} = {%{$SERVICE_TEMPL->{60}}};
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Command'}->{probe} = 'hr.srce/GRAM-probe';
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Command'}->{dependency}->{"hr.srce.GRAM-Auth"} = 1;
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Command'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
#$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Command'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Command'}->{attribute}->{VONAME} = "-v";
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Command'}->{vo} = 1;

$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-CertLifetime'}->{config} = {%{$SERVICE_TEMPL->{1440}}};
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-CertLifetime'}->{probe} = 'hr.srce/GRAM-probe';

# MyProxy
$WLCG_SERVICE->{MyProxy}->{metrics}->{'hr.srce.MyProxy-Store'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{MyProxy}->{metrics}->{'hr.srce.MyProxy-Store'}->{probe} = 'hr.srce/MyProxy-probe';
$WLCG_SERVICE->{MyProxy}->{metrics}->{'hr.srce.MyProxy-Store'}->{dependency}->{"hr.srce.MyProxy-CertLifetime"} = 1;
$WLCG_SERVICE->{MyProxy}->{metrics}->{'hr.srce.MyProxy-Store'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
#$WLCG_SERVICE->{MyProxy}->{metrics}->{'hr.srce.MyProxy-Store'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{MyProxy}->{metrics}->{'hr.srce.MyProxy-Store'}->{attribute}->{VONAME} = "-v";
$WLCG_SERVICE->{MyProxy}->{metrics}->{'hr.srce.MyProxy-Store'}->{vo} = 1;

$WLCG_SERVICE->{MyProxy}->{metrics}->{'hr.srce.MyProxy-CertLifetime'}->{config} = {%{$SERVICE_TEMPL->{1440}}};
$WLCG_SERVICE->{MyProxy}->{metrics}->{'hr.srce.MyProxy-CertLifetime'}->{probe} = 'hr.srce/MyProxy-probe';

# SRM1
$WLCG_SERVICE->{SRM1}->{metrics}->{'hr.srce.SRM1-CertLifetime'}->{config} = {%{$SERVICE_TEMPL->{1440}}};
$WLCG_SERVICE->{SRM1}->{metrics}->{'hr.srce.SRM1-CertLifetime'}->{probe} = 'hr.srce/SRM-probe';
$WLCG_SERVICE->{SRM1}->{metrics}->{'hr.srce.SRM1-CertLifetime'}->{dependency}->{"org.nagios.SRM1-PortCheck"} = 1;

$WLCG_SERVICE->{SRM1}->{metrics}->{'hr.srce.SRM1-Ping'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{SRM1}->{metrics}->{'hr.srce.SRM1-Ping'}->{probe} = 'hr.srce/SRM-probe';
$WLCG_SERVICE->{SRM1}->{metrics}->{'hr.srce.SRM1-Ping'}->{dependency}->{"hr.srce.SRM1-CertLifetime"} = 1;
$WLCG_SERVICE->{SRM1}->{metrics}->{'hr.srce.SRM1-Ping'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
#$WLCG_SERVICE->{SRM1}->{metrics}->{'hr.srce.SRM1-Ping'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{SRM1}->{metrics}->{'hr.srce.SRM1-Ping'}->{attribute}->{VONAME} = "-v";
$WLCG_SERVICE->{SRM1}->{metrics}->{'hr.srce.SRM1-Ping'}->{vo} = 1;

$WLCG_SERVICE->{SRM1}->{metrics}->{'hr.srce.SRM-Transfer'}->{config} = {%{$SERVICE_TEMPL->{60}}};
$WLCG_SERVICE->{SRM1}->{metrics}->{'hr.srce.SRM-Transfer'}->{probe} = 'hr.srce/SRM-probe';
$WLCG_SERVICE->{SRM1}->{metrics}->{'hr.srce.SRM-Transfer'}->{dependency}->{"hr.srce.SRM1-CertLifetime"} = 1;
$WLCG_SERVICE->{SRM1}->{metrics}->{'hr.srce.SRM-Transfer'}->{dependency}->{"hr.srce.SRM1-Ping"} = 1;
$WLCG_SERVICE->{SRM1}->{metrics}->{'hr.srce.SRM-Transfer'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
$WLCG_SERVICE->{SRM1}->{metrics}->{'hr.srce.SRM-Transfer'}->{attribute}->{SE_PATH} = "--path";
#$WLCG_SERVICE->{SRM1}->{metrics}->{'hr.srce.SRM-Transfer'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{SRM1}->{metrics}->{'hr.srce.SRM-Transfer'}->{attribute}->{VONAME} = "-v";
$WLCG_SERVICE->{SRM1}->{metrics}->{'hr.srce.SRM-Transfer'}->{vo} = 1;

# SRM v2 - No tools on UI yet - just try simple port probe and cert check
$WLCG_SERVICE->{SRM2}->{metrics}->{'hr.srce.SRM2-CertLifetime'}->{config} = {%{$SERVICE_TEMPL->{1440}}};
$WLCG_SERVICE->{SRM2}->{metrics}->{'hr.srce.SRM2-CertLifetime'}->{probe} = 'hr.srce/SRM-probe';
$WLCG_SERVICE->{SRM2}->{metrics}->{'hr.srce.SRM2-CertLifetime'}->{dependency}->{"org.nagios.SRM2-PortCheck"} = 1;

# DPNS
$WLCG_SERVICE->{DPNS}->{metrics}->{'hr.srce.DPNS-List'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{DPNS}->{metrics}->{'hr.srce.DPNS-List'}->{probe} = 'hr.srce/DPNS-probe';
$WLCG_SERVICE->{DPNS}->{metrics}->{'hr.srce.DPNS-List'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
#$WLCG_SERVICE->{DPNS}->{metrics}->{'hr.srce.DPNS-List'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{DPNS}->{metrics}->{'hr.srce.DPNS-List'}->{attribute}->{VONAME} = "-v";
$WLCG_SERVICE->{DPNS}->{metrics}->{'hr.srce.DPNS-List'}->{vo} = 1;

# Resource Broker
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-RunJob'}->{config}->{interval} = 60;
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-RunJob'}->{config}->{timeout} = 900;
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-RunJob'}->{config}->{retryInterval} = 20;
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-RunJob'}->{probe} = 'hr.srce/ResourceBroker-probe';
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-RunJob'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-RunJob'}->{dependency}->{"hr.srce.GridFTP-Transfer"} = 1;
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-RunJob'}->{dependency}->{"org.nagios.ResourceBroker-PortCheck"} = 1;
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-RunJob'}->{dependency}->{"org.nagios.LocalLogger-PortCheck"} = 1;
#$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-RunJob'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-RunJob'}->{attribute}->{VONAME} = "-v";
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-RunJob'}->{vo} = 1;

$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-CertLifetime'}->{config} = {%{$SERVICE_TEMPL->{1440}}};
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-CertLifetime'}->{probe} = 'hr.srce/ResourceBroker-probe';
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-CertLifetime'}->{dependency}->{"org.nagios.LocalLogger-PortCheck"} = 1;

# LFC
$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-Write'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-Write'}->{probe} = 'ch.cern/LFC-probe';
$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-Write'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
#$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-Write'}->{attribute}->{PROXY_PATH} = "";
$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-Write'}->{attribute}->{VONAME} = "-v";
$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-Write'}->{vo} = 1;

$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-Read'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-Read'}->{probe} = 'ch.cern/LFC-probe';
$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-Read'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-Read'}->{dependency}->{"ch.cern.LFC-Write"} = 1;
#$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-Read'}->{attribute}->{PROXY_PATH} = "";
$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-Read'}->{attribute}->{VONAME} = "-v";
$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-Read'}->{vo} = 1;

$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-Readdir'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-Readdir'}->{probe} = 'ch.cern/LFC-probe';
$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-Readdir'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
#$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-Readdir'}->{attribute}->{PROXY_PATH} = "";
$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-Readdir'}->{attribute}->{VONAME} = "-v";
$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-Readdir'}->{vo} = 1;

$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-ReadDli'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-ReadDli'}->{probe} = 'ch.cern/LFC-probe';
$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-ReadDli'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-Read'}->{dependency}->{"ch.cern.LFC-Write"} = 1;
#$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-ReadDli'}->{attribute}->{PROXY_PATH} = "";
$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-ReadDli'}->{attribute}->{VONAME} = "-v";
$WLCG_SERVICE->{'gLite-LFC'}->{metrics}->{'ch.cern.LFC-ReadDli'}->{vo} = 1;

# Resource Broker
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-RunJob'}->{config}->{interval} = 60;
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-RunJob'}->{config}->{timeout} = 900;
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-RunJob'}->{config}->{retryInterval} = 20;
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-RunJob'}->{probe} = 'hr.srce/WMS-probe';
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-RunJob'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-RunJob'}->{dependency}->{"hr.srce.GridFTP-Transfer"} = 1;
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-RunJob'}->{dependency}->{"org.nagios.NetworkServer-PortCheck"} = 1;
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-RunJob'}->{dependency}->{"org.nagios.LocalLogger-PortCheck"} = 1;
#$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-RunJob'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-RunJob'}->{attribute}->{VONAME} = "-v";
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-RunJob'}->{vo} = 1;

$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-CertLifetime'}->{config} = {%{$SERVICE_TEMPL->{1440}}};
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-CertLifetime'}->{probe} = 'hr.srce/WMS-probe';
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-CertLifetime'}->{dependency}->{"org.nagios.LocalLogger-PortCheck"} = 1;

# org.glite.wms.WMProxy
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-RunJob'}->{config}->{interval} = 60;
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-RunJob'}->{config}->{timeout} = 900;
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-RunJob'}->{config}->{retryInterval} = 20;
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-RunJob'}->{probe} = 'hr.srce/WMProxy-probe';
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-RunJob'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-RunJob'}->{dependency}->{"hr.srce.GridFTP-Transfer"} = 1;
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-RunJob'}->{dependency}->{"org.nagios.WMProxy-PortCheck"} = 1;
#$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-RunJob'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-RunJob'}->{attribute}->{VONAME} = "-v";
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-RunJob'}->{vo} = 1;

$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-CertLifetime'}->{config} = {%{$SERVICE_TEMPL->{1440}}};
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-CertLifetime'}->{probe} = 'hr.srce/WMProxy-probe';
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-CertLifetime'}->{dependency}->{"org.nagios.WMProxy-PortCheck"} = 1;


$WLCG_SERVICE->{CAdistribution}->{metrics}->{'hr.srce.CAdist-Version'}->{config} = {%{$SERVICE_TEMPL->{1440}}};
$WLCG_SERVICE->{CAdistribution}->{metrics}->{'hr.srce.CAdist-Version'}->{probe} = 'hr.srce/CAdist-probe';
$WLCG_SERVICE->{CAdistribution}->{metrics}->{'hr.srce.CAdist-Version'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;

# gLite-RGMA
$WLCG_SERVICE->{'gLite-RGMA'}->{metrics}->{'ch.cern.RGMA-ServiceStatus'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'gLite-RGMA'}->{metrics}->{'ch.cern.RGMA-ServiceStatus'}->{probe} = 'ch.cern/RGMA-probe';
$WLCG_SERVICE->{'gLite-RGMA'}->{metrics}->{'ch.cern.RGMA-ServiceStatus'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
$WLCG_SERVICE->{'gLite-RGMA'}->{metrics}->{'ch.cern.RGMA-ServiceStatus'}->{dependency}->{"org.nagios.Tomcat-Check"} = 1;
#$WLCG_SERVICE->{'gLite-RGMA'}->{metrics}->{'ch.cern.RGMA-ServiceStatus'}->{attribute}->{PROXY_PATH} = "-x";

#
# SSL not supported yet ?
#$WLCG_SERVICE->{'glite-RGMA'}->{metrics}->{'hr.srce.RGMA-CertLifetime'}->{config} = {%{$SERVICE_TEMPL->{1440}}};
#$WLCG_SERVICE->{'glite-RGMA'}->{metrics}->{'hr.srce.RGMA-CertLifetime'}->{probe} = 'ch.cern/RGMA-probe';

# gLite-FTS-WS
$WLCG_SERVICE->{'gLite-FTS-WS'}->{metrics}->{'ch.cern.FTS-ChannelList'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'gLite-FTS-WS'}->{metrics}->{'ch.cern.FTS-ChannelList'}->{probe} = 'ch.cern/FTS-probe';
$WLCG_SERVICE->{'gLite-FTS-WS'}->{metrics}->{'ch.cern.FTS-ChannelList'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
$WLCG_SERVICE->{'gLite-FTS-WS'}->{metrics}->{'ch.cern.FTS-ChannelList'}->{dependency}->{"org.nagios.Tomcat-Check"} = 1;
#$WLCG_SERVICE->{'gLite-FTS-WS'}->{metrics}->{'ch.cern.FTS-ChannelList'}->{attribute}->{PROXY_PATH} = "-x";

# DPNS
$WLCG_SERVICE->{DPNS}->{metrics}->{'hr.srce.DPNS-List'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{DPNS}->{metrics}->{'hr.srce.DPNS-List'}->{probe} = 'hr.srce/DPNS-probe';
$WLCG_SERVICE->{DPNS}->{metrics}->{'hr.srce.DPNS-List'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
#$WLCG_SERVICE->{DPNS}->{metrics}->{'hr.srce.DPNS-List'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{DPNS}->{metrics}->{'hr.srce.DPNS-List'}->{attribute}->{VONAME} = "-v";

# Native services

# Main difference is that we don't know anything about parameters, so all of them
# need to define in attribute hash

# GridFTP-Ping
$WLCG_SERVICE->{gsiftp}->{metrics}->{'org.nagios.GridFTP-Check'}->{native} = "Nagios";
$WLCG_SERVICE->{gsiftp}->{metrics}->{'org.nagios.GridFTP-Check'}->{probe} = "check_ftp";
$WLCG_SERVICE->{gsiftp}->{metrics}->{'org.nagios.GridFTP-Check'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{gsiftp}->{metrics}->{'org.nagios.GridFTP-Check'}->{config}->{timeout} = 60;
$WLCG_SERVICE->{gsiftp}->{metrics}->{'org.nagios.GridFTP-Check'}->{attribute}->{GRIDFTP_PORT} = "-p";

# BDII
$WLCG_SERVICE->{BDII}->{metrics}->{'org.nagios.BDII-Check'}->{native} = "Nagios";
$WLCG_SERVICE->{BDII}->{metrics}->{'org.nagios.BDII-Check'}->{probe} = "check_ldap";
$WLCG_SERVICE->{BDII}->{metrics}->{'org.nagios.BDII-Check'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{BDII}->{metrics}->{'org.nagios.BDII-Check'}->{config}->{timeout} = 60;
$WLCG_SERVICE->{BDII}->{metrics}->{'org.nagios.BDII-Check'}->{attribute}->{BDII_DN} = "-b";
$WLCG_SERVICE->{BDII}->{metrics}->{'org.nagios.BDII-Check'}->{attribute}->{BDII_PORT} = "-p";

# MDS-GIIS
$WLCG_SERVICE->{'MDS-GIIS'}->{metrics}->{'org.nagios.MDS-Check'}->{native} = "Nagios";
$WLCG_SERVICE->{'MDS-GIIS'}->{metrics}->{'org.nagios.MDS-Check'}->{probe} = "check_ldap";
$WLCG_SERVICE->{'MDS-GIIS'}->{metrics}->{'org.nagios.MDS-Check'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'MDS-GIIS'}->{metrics}->{'org.nagios.MDS-Check'}->{config}->{timeout} = 60;
$WLCG_SERVICE->{'MDS-GIIS'}->{metrics}->{'org.nagios.MDS-Check'}->{attribute}->{MDS_DN} = "-b";
$WLCG_SERVICE->{'MDS-GIIS'}->{metrics}->{'org.nagios.MDS-Check'}->{attribute}->{MDS_PORT} = "-p";

# it.infn.GridICE
$WLCG_SERVICE->{'it.infn.GridICE'}->{metrics}->{'org.nagios.GridICE-Check'}->{native} = "Nagios";
$WLCG_SERVICE->{'it.infn.GridICE'}->{metrics}->{'org.nagios.GridICE-Check'}->{probe} = "check_ldap";
$WLCG_SERVICE->{'it.infn.GridICE'}->{metrics}->{'org.nagios.GridICE-Check'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'it.infn.GridICE'}->{metrics}->{'org.nagios.GridICE-Check'}->{config}->{timeout} = 60;
$WLCG_SERVICE->{'it.infn.GridICE'}->{metrics}->{'org.nagios.GridICE-Check'}->{attribute}->{GRIDICE_DN} = "-b";
$WLCG_SERVICE->{'it.infn.GridICE'}->{metrics}->{'org.nagios.GridICE-Check'}->{attribute}->{GRIDICE_PORT} = "-p";

# Tomcat
$WLCG_SERVICE->{Tomcat}->{metrics}->{'org.nagios.Tomcat-Check'}->{native} = "Nagios";
$WLCG_SERVICE->{Tomcat}->{metrics}->{'org.nagios.Tomcat-Check'}->{probe} = "check_tcp";
$WLCG_SERVICE->{Tomcat}->{metrics}->{'org.nagios.Tomcat-Check'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{Tomcat}->{metrics}->{'org.nagios.Tomcat-Check'}->{config}->{timeout} = 60;
$WLCG_SERVICE->{Tomcat}->{metrics}->{'org.nagios.Tomcat-Check'}->{attribute}->{TOMCAT_PORT} = "-p";

# SRM v1
$WLCG_SERVICE->{SRM1}->{metrics}->{'org.nagios.SRM1-PortCheck'}->{native} = "Nagios";
$WLCG_SERVICE->{SRM1}->{metrics}->{'org.nagios.SRM1-PortCheck'}->{probe} = "check_tcp";
$WLCG_SERVICE->{SRM1}->{metrics}->{'org.nagios.SRM1-PortCheck'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{SRM1}->{metrics}->{'org.nagios.SRM1-PortCheck'}->{config}->{timeout} = 60;
$WLCG_SERVICE->{SRM1}->{metrics}->{'org.nagios.SRM1-PortCheck'}->{attribute}->{SRM1_PORT} = "-p";
# SRM v2
$WLCG_SERVICE->{SRM2}->{metrics}->{'org.nagios.SRM2-PortCheck'}->{native} = "Nagios";
$WLCG_SERVICE->{SRM2}->{metrics}->{'org.nagios.SRM2-PortCheck'}->{probe} = "check_tcp";
$WLCG_SERVICE->{SRM2}->{metrics}->{'org.nagios.SRM2-PortCheck'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{SRM2}->{metrics}->{'org.nagios.SRM2-PortCheck'}->{config}->{timeout} = 60;
$WLCG_SERVICE->{SRM2}->{metrics}->{'org.nagios.SRM2-PortCheck'}->{attribute}->{SRM2_PORT} = "-p";

# EDG/gLite Locallogger - check only port
$WLCG_SERVICE->{'org.glite.LocalLogger'}->{metrics}->{'org.nagios.LocalLogger-PortCheck'}->{native} = "Nagios";
$WLCG_SERVICE->{'org.glite.LocalLogger'}->{metrics}->{'org.nagios.LocalLogger-PortCheck'}->{probe} = "check_tcp";
$WLCG_SERVICE->{'org.glite.LocalLogger'}->{metrics}->{'org.nagios.LocalLogger-PortCheck'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'org.glite.LocalLogger'}->{metrics}->{'org.nagios.LocalLogger-PortCheck'}->{config}->{timeout} = 60;
$WLCG_SERVICE->{'org.glite.LocalLogger'}->{metrics}->{'org.nagios.LocalLogger-PortCheck'}->{attribute}->{LL_PORT} = "-p";

# Resource Broker
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'org.nagios.ResourceBroker-PortCheck'}->{native} = "Nagios";
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'org.nagios.ResourceBroker-PortCheck'}->{probe} = "check_tcp";
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'org.nagios.ResourceBroker-PortCheck'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'org.nagios.ResourceBroker-PortCheck'}->{config}->{timeout} = 60;
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'org.nagios.ResourceBroker-PortCheck'}->{attribute}->{RB_PORT} = "-p";

# WMProxy Broker
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'org.nagios.WMProxy-PortCheck'}->{native} = "Nagios";
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'org.nagios.WMProxy-PortCheck'}->{probe} = "check_tcp";
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'org.nagios.WMProxy-PortCheck'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'org.nagios.WMProxy-PortCheck'}->{config}->{timeout} = 60;
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'org.nagios.WMProxy-PortCheck'}->{attribute}->{WMPROXY_PORT} = "-p";

# WMProxy Broker
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'org.nagios.NetworkServer-PortCheck'}->{native} = "Nagios";
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'org.nagios.NetworkServer-PortCheck'}->{probe} = "check_tcp";
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'org.nagios.NetworkServer-PortCheck'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'org.nagios.NetworkServer-PortCheck'}->{config}->{timeout} = 60;
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'org.nagios.NetworkServer-PortCheck'}->{attribute}->{WMS_PORT} = "-p";

# VOBOX gsissh
$WLCG_SERVICE->{'gsissh'}->{metrics}->{'org.nagios.gsissh-Check'}->{native} = 1;
$WLCG_SERVICE->{'gsissh'}->{metrics}->{'org.nagios.gsissh-Check'}->{probe} = "check_ssh";
$WLCG_SERVICE->{'gsissh'}->{metrics}->{'org.nagios.gsissh-Check'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'gsissh'}->{metrics}->{'org.nagios.gsissh-Check'}->{config}->{timeout} = 60;
$WLCG_SERVICE->{'gsissh'}->{metrics}->{'org.nagios.gsissh-Check'}->{attribute}->{VOBOX_PORT} = "-p";

#
# OSG Metrics - testing
#
# GRAM service
$WLCG_SERVICE->{'OSG-GRAM'}->{metrics}->{'org.osg.globus.gram-authentication'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'OSG-GRAM'}->{metrics}->{'org.osg.globus.gram-authentication'}->{probe} = 'org.osg/resource_service_availability/gram-authentication-probe';
$WLCG_SERVICE->{'OSG-GRAM'}->{metrics}->{'org.osg.globus.gram-authentication'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
$WLCG_SERVICE->{'OSG-GRAM'}->{metrics}->{'org.osg.globus.gram-authentication'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{'OSG-GRAM'}->{metrics}->{'org.osg.globus.gram-authentication'}->{attribute}->{VDT_LOCATION} = "--vdt-location";

$WLCG_SERVICE->{'OSG-GRAM'}->{metrics}->{'org.osg.general.ping-host'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'OSG-GRAM'}->{metrics}->{'org.osg.general.ping-host'}->{probe} = 'org.osg/resource_service_availability/ping-host-probe';
$WLCG_SERVICE->{'OSG-GRAM'}->{metrics}->{'org.osg.general.ping-host'}->{attribute}->{VDT_LOCATION} = "--vdt-location";

# Gridftp to/from CE
$WLCG_SERVICE->{'OSG-Gridftp'}->{metrics}->{'org.osg.globus.gridftp-simple'}->{config} = {%{$SERVICE_TEMPL->{15}}}; 
$WLCG_SERVICE->{'OSG-Gridftp'}->{metrics}->{'org.osg.globus.gridftp-simple'}->{probe} = 'org.osg/resource_service_availability/gridftp-simple-probe';
$WLCG_SERVICE->{'OSG-Gridftp'}->{metrics}->{'org.osg.globus.gridftp-simple'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
#$WLCG_SERVICE->{'OSG-Gridftp'}->{metrics}->{'org.osg.globus.gridftp-simple'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{'OSG-Gridftp'}->{metrics}->{'org.osg.globus.gridftp-simple'}->{attribute}->{VDT_LOCATION} = "--vdt-location";
$WLCG_SERVICE->{'OSG-Gridftp'}->{metrics}->{'org.osg.globus.gridftp-simple'}->{attribute}->{OSG_TEST_FILE} = "--testfile";

# CA Cert expiry
$WLCG_SERVICE->{'OSG-GSI'}->{metrics}->{'org.osg.certificates.cacert-expiry'}->{config} = {%{$SERVICE_TEMPL->{15}}}; 
$WLCG_SERVICE->{'OSG-GSI'}->{metrics}->{'org.osg.certificates.cacert-expiry'}->{probe} = 'org.osg/resource_service_availability/cacert-crl-expiry-probe';
$WLCG_SERVICE->{'OSG-GSI'}->{metrics}->{'org.osg.certificates.cacert-expiry'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
#$WLCG_SERVICE->{'OSG-GSI'}->{metrics}->{'org.osg.certificates.cacert-expiry'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{'OSG-GSI'}->{metrics}->{'org.osg.certificates.cacert-expiry'}->{attribute}->{VDT_LOCATION} = "--vdt-location";

# CRL expiry
$WLCG_SERVICE->{'OSG-GSI'}->{metrics}->{'org.osg.certificates.crl-expiry'}->{config} = {%{$SERVICE_TEMPL->{15}}}; 
$WLCG_SERVICE->{'OSG-GSI'}->{metrics}->{'org.osg.certificates.crl-expiry'}->{probe} = 'org.osg/resource_service_availability/cacert-crl-expiry-probe';
$WLCG_SERVICE->{'OSG-GSI'}->{metrics}->{'org.osg.certificates.crl-expiry'}->{dependency}->{"hr.srce.GridProxy-Valid"} = 0;
#$WLCG_SERVICE->{'OSG-GSI'}->{metrics}->{'org.osg.certificates.crl-expiry'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{'OSG-GSI'}->{metrics}->{'org.osg.certificates.crl-expiry'}->{attribute}->{VDT_LOCATION} = "--vdt-location";

# These tests currently also work on a EGEE CE  - 
#push @{$WLCG_NODETYPE->{CE}->{services}}, "OSG-GRAM", "OSG-Gridftp"; 
# - OSG-GSI checks for cert/ca files in $VDT_LOCATION/globus/share/certificates which isn't correct on EGEE
#push @{$WLCG_NODETYPE->{CE}->{services}}, "OSG-GSI";

########################################################################


=head1 NAME

NCG::LocalMetrics::Hash

=head1 DESCRIPTION

The NCG::LocalMetrics::Hash module extends NCG::LocalMetrics module.
Module extracts metric information from hard-coded hash.

=head1 SYNOPSIS

  use NCG::LocalMetrics::Hash;

  my $lms = NCG::LocalMetrics::Hash->new( { SITEDB=> $sitedb,
                                    NATIVE => 'Nagios' } );

  $lms->getData();

=cut

=head1 METHODS

=over

=item C<new>

  $siteInfo = NCG::LocalMetrics::Hash->new( $options );

Creates new NCG::LocalMetrics::Hash instance. Argument $options is hash
reference that can contain following elements:
  NATIVE - name of underlying monitoring system; if set this
  variable is used to filter metrics gathered by using native
  probes (e.g. Nagios: check_tcp, check_ftp). If not set,
  all defined metrics will be loaded.

=back

=head1 SEE ALSO

NCG::LocalMetrics

=cut

1;
