#!/usr/bin/perl -w
#
# Nagios configuration generator (WLCG probe based)
# Copyright (c) 2007 Emir Imamagic
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package NCG::LocalRules;

use strict;
use NCG;
use vars qw(@ISA);

@ISA=("NCG");

sub new
{
    my $proto  = shift;
    my $class  = ref($proto) || $proto;
    my $self =  $class->SUPER::new(@_);
    $self;
}

=head1 NAME

NCG::LocalRules

=head1 DESCRIPTION

The NCG::LocalRules module is abstract class for all modules
which apply local rules to information gathered. Each module
extending NCG::LocalRules must implement method applyRules.

=head1 SYNOPSIS

  use NCG::LocalRules;
  $ncg = NCG::LocalRules->new( $attr );
  $ncg->getData ();

=cut

=head1 METHODS

=over

=item C<new>

  $dbh = NCG::LocalRules->new( $attr );

Creates new NCG::LocalRules instance.

=item C<getData>

  $ncg->getData ();

Abstract method for applying local rules on SiteDB object.

=back

=head1 SEE ALSO

=cut

1;
