#!/usr/bin/perl -w
#
# Nagios configuration generator (WLCG probe based)
# Copyright (c) 2007 Emir Imamagic
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package NCG::SiteInfo;

use strict;
use NCG;
use vars qw(@ISA);

@ISA=("NCG");

sub new
{
    my $proto  = shift;
    my $class  = ref($proto) || $proto;
    my $self =  $class->SUPER::new(@_);
    $self;
}

=head1 NAME

NCG::SiteInfo

=head1 DESCRIPTION

The NCG::SiteInfo module is abstract class for extracting information
from various information sources about grid site. Each module extending
NCG::SiteInfo must implement method getServices.

Main purpose of this module is to get list of tuples (host, service, VO).
Currently supported information sources are SAM, LDAP based information
sources (BDII, Globus MDS), GOCDB and static file.

This module is primarily used by ncg.pl program for generating Nagios
configuration for grid sites. However, it can be used by any other
tools for extracting basic site/service information.

=head1 SYNOPSIS

  use NCG::SiteInfo;
  my $ncg = NCG::SiteInfo->new($options);
  $res = $ncg->getData();

=cut

=head1 METHODS

=over

=item C<new>

  $dbh = NCG::SiteInfo->new( $attr );

Creates new NCG::SiteInfo instance.

=item C<getData>

  $res = $dbh->getData();

Abstract method for gathering site information.

=back

=head1 SEE ALSO

=cut

1;
